
# q-expansion of newform 285.10.a.f, downloaded from the LMFDB on 15 January 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 285
weight = 10
poly_data = [-480881506516992, -9924122935296, 12984029397983232, 3954911489638400, -831531966469120, -15731969979520, 4820661863456, 24552331696, -10608934432, -19024208, 10970098, 7107, -5365, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-767, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[1231, -1275, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-315448113579074369130907645704209597875914753441792, -140908630446597899001534155625573359715753010356224, 81029371618296008202880354914058238264279505801216, -3863469178299555514527064542336356279241768467456, -431260582197223426977342939736071558252193319424, 24285171026449786375093924404812687844016600864, 857414082900183518896452642515981291398412432, -53122538123203308355851682144617301059695616, -807850588738802969423304754252552705545976, 54319491589234178835231919811646500487858, 363409002530420180018597470663181651245, -26373157546161633305443701821850602763, -62857010501899966722123412646421207, 4900218087837623915634893591959211], 6845603837399132376035489683084780424790016000], [[38247113545995757928826352741634327165423836463104, -192577262445550688498735178689106058809634095194112, -66622659981356012216457074490024826600401220923392, 13090705158412431801255593215401431441684084278272, 278252145572731791915449326192188724446201036288, -76234344806337829586957502970607302927974649568, -466501765332003453300786605560854237648540784, 168137873615157569340500650036022568205000192, 395129443058893105004546246237337155893512, -174122221060042179818375714593923081014446, -164406131023662663578558706743824129315, 85246949467837778211236523666579174181, 26468200058769800381908066491981209, -15901641035813498247699453870533957], 6845603837399132376035489683084780424790016000], [[-356986397466516079492513230866239687209757317791744, 1164053311945222473942748635312229406480920606892032, 458231256761718002480860862695118810152912177754112, -88746145151110049438914502618057635920924865569792, -1879239015587353238465674186420511221166260602368, 519438057753965678939470286304110525869862516448, 3075264102662884232346074818825051321472538224, -1147805729489501058682324264181184739016038912, -2529897662871812056511067205526190652855432, 1190266593269177333338107804273424982613806, 1016952607153801606872567705442653075715, -583393756611539569404917790997026019141, -157073433002404415918936223301150649, 108928834617529477330767597786343077], 6845603837399132376035489683084780424790016000], [[420003060766545120099729705310221344088698454016, 5648022596722342737736598528508825977091472535552, 1580029197588333994018124791713564406945551224832, -339688028192128412551642022794244320499073056512, -6220816016830840842657717165568743000470072448, 1956335478092771712943975087070787488073548128, 9502329892327322237640160355844334470489264, -4288966276240449532011678316141144850558832, -7121770652595085276087182643580702591952, 4422182245936477365352697332038694218766, 2536806916716894034611999581946999715, -2157720080817296878474359123571123701, -332438566721370842809460717423089, 401437382502311672911702577374597], 21392511991872288675110905259639938827468800], [[-137081274462635821058458907123391546390297526140928, 679666321432741690571225208651195756812242691088384, 296020121189707889428416015030508448413970274873344, -54517457629277381317141260377587182465323825685504, -1250271498756576012761403894789219013169069820416, 318558895477480093841025762253126788726825601376, 2076275374167379152386768421709422497945920688, -701627921896770141574927194910499667840594944, -1704847258571429827638391371066865259782184, 725263741376271789601163402639824471022422, 676806527626564860335764943800571754455, -354516902681314985567165908783673988817, -102613549264818695051497920091759413, 66050270270298238487746273683276049], 3422801918699566188017744841542390212395008000], [[-22246668445037199146662656258122358312006231523328, -480613292011336859218168754173888517986011766972416, -135725454232154982137836962236548921832100302483456, 29247958118911623334455782823610288634699293008896, 543980097003868254436426760280213687828264221184, -169610339259495471495131473131486150548855113824, -869180654411690324144328383202699404360433712, 374253281790593689053260339215612956988064256, 700563595979045606285165599762626832090216, -388140461178851619182281360797389599454278, -275807835941852839511819740980809789295, 190342261742898017950499016626719072633, 41523910688747285555839805654778237, -35562626515206326088686948965471801], 1369120767479826475207097936616956084958003200], [[-30091067266563012609000606319863578273703788019712, 91447728321659026380562454300442581665953719361536, 39842372333389123194137623314151289361215600357376, -7387864454963305168388767056305573887984349910016, -165153343775880148332556804711578843475091057664, 43329678701182681711636262666329892618798553504, 269664770170376286008087825675176140629692752, -95656552231244951564407177094944742210827776, -218557329506639947482204841396628320263736, 99023074625214439092071543999457607822938, 85840399763428710567982263859035837945, -48446658521985415326441052947111290143, -12875067395685993074000163431312027, 9030883240627816427924177054717071], 311163810790869653456158621958399110217728000], [[131021730717265342967675437285363839467341481508864, -764014754201471234687752698954134686379245022011392, -246096515426100483095157842808668758619541990735872, 49957057157933852930296813736003874443024001533952, 990858593271361964271181832848571644563651403008, -289340101107657974528638154119948202795404835488, -1570291654938918009800426274702939773738393744, 636078625077594024367667528855918285658076672, 1236081520412017551195736215591604584618792, -657239951362286199572335161080499265158186, -469911158241737432335239339714772856165, 321272952321383094388089342412771627571, 67605902877984803803065090086255919, -59865551916786748339233107309055787], 1711400959349783094008872420771195106197504000], [[14653934630898919532435528762486188502911798345728, 74699769761294720365450003158307159432797693935616, 24435264045118765384819775121073130168994704275456, -5197125553442743943116334730185092338362846404096, -95891328799187734253191281187910491358279968384, 30289787592305867842520475296975783094123568224, 147181579640308201110213340229919545518727312, -66765560810344622548737987778974173402093056, -112142265049974468074813478040618239927616, 69083998440213458933085272451049112021478, 41157195994350598288918382135870346945, -33797609139997667613988140673939662983, -5666548533112145422317063071490587, 6301048700522493566598499422990251], 171140095934978309400887242077119510619750400], [[-164418524052482661513145226549811211261953364721664, 7576662979984291529667438371062030203161284487585792, 2246449131452732306262630259563425664911768825270272, -478938053642316908978090747830765659105737481444352, -8809157901012243575809461506959800323733553412608, 2775679878651591341432833197912078901120575117088, 13476105225622715617118033655500310338593894544, -6108595602290582142430031937361232110646467072, -10176643755765790712807316239262624093043192, 6316757365937718800347325373367798656062386, 3674228352046455531950623940346479621165, -3089341519906794562164110770007231605771, -492099795241761108354751559189269719, 575848205048197206204737957327702187], 6845603837399132376035489683084780424790016000]]

hecke_ring_character_values = None
aps_data = [[0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-81, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-625, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [934, -23, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [3135, -462, -15, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0], [18297, 523, -26, 3, 1, -2, -1, 0, -1, 1, 0, 0, 0, 0], [-6490, -1292, -125, -11, 0, 8, 0, 1, -3, -1, 0, -3, 0, -3], [130321, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-116896, 8131, 120, -43, 1, 4, -7, 7, -3, 4, -4, 6, 2, 4], [-225883, 19979, -977, -86, -46, 163, -14, 0, -4, -33, -13, -5, 1, -5], [18024, -20759, 2430, -61, -6, 143, -50, -38, -9, -5, 43, -20, 1, -12], [2108282, -40089, 4418, 85, -63, 56, -117, -86, -11, -47, 25, -4, 1, -4], [-1289364, -140886, 8431, -531, 131, 786, -11, 59, -139, 21, 38, -116, -30, -76], [1859498, 80559, 10136, -507, 55, 654, 41, -6, -43, 39, -105, -18, 135, -106], [1140634, 50846, 10548, 2021, 99, -2540, 7, 328, -289, -15, 21, -21, -59, 57], [1717796, 73755, 18962, 727, 9, -3130, 169, 589, 263, 118, -34, -90, 28, -56], [-3647986, -423438, 18569, 1659, 453, -3916, -347, 60, -441, 862, -201, -698, -59, 296], [-19025250, -865421, 31341, 1432, 185, -651, -619, -162, -428, -107, 130, -144, 86, -18], [25450076, -1837202, 68379, -252, -1120, 1771, -142, 298, 736, -693, 564, -134, -578, -1044], [12871630, -1946091, 37917, -4704, 1362, 4793, 64, 1641, 262, -2032, -1485, 867, -133, 97], [40884650, -484364, 78165, 3484, 1820, 5843, -398, 8, 856, 443, -590, -1002, 452, 1192], [32906466, -4171207, -23895, 449, -815, 24628, -1211, -5525, -1369, 2587, 194, -3139, -34, -997], [19938176, -3983932, 10255, -13604, -346, 35306, -1026, 2614, 1102, -3321, 546, 1579, -1896, -209], [-142423599, -12541827, -139503, -24859, -909, 20864, -2767, -2184, -2225, -912, 5002, 1517, 1780, -411], [115561188, -11335955, -53447, 28035, 1603, -13773, 2787, 5924, -6281, 1234, 993, 644, -629, 4478], [-130720588, -10211490, -698500, 21870, 1916, -15686, 1364, 2006, 5842, 44, -2486, 5300, -3178, -3464], [73199710, -8960798, -431629, 51162, 2684, -2363, 708, 532, 2420, 4587, -7686, 6980, 2290, 5444], [110139302, -13817896, -539816, -51476, 8208, 59032, 6818, 7872, -3242, -9680, -6698, 6216, -8468, 6862], [-60955782, -4113251, 280739, 16081, 14885, 4034, 11181, 9653, 3575, 4399, -3322, 4069, 4254, -2317], [-444577546, -2496063, -386126, 23409, -17297, 49174, 2595, 16929, 1637, -9052, 6610, -6694, 12136, -12228], [704867006, -33262980, 1093796, -48538, -18678, -136270, -9192, 7944, 17488, -15578, 14400, -10540, -4394, -28054], [-807864886, -21260209, -838011, -85828, 1654, -13913, -5170, 1692, -24486, -3565, 3956, -24417, 14438, 8431], [-458642800, -42723055, -1190107, -32627, -35173, 103284, -16617, -35571, 8483, 21501, 14440, -50533, -1984, -6915], [796730150, -68435673, -469100, 121978, -5100, -8452, -2076, -46137, -7852, 18205, 14633, -19509, 6987, 6683], [1496106548, -53124565, 3093833, -12380, 32918, 171563, 32684, -1447, 20238, 17732, -3637, 45079, 3023, -1415], [1306887624, -24763594, -2198120, -19171, 28436, -246833, 9048, -29573, -27429, 30548, -74656, 8953, 4916, 27325], [2442276298, -60315650, 1624543, 154639, 20495, -598980, -15127, -36530, -56407, -7398, -28361, -11782, -7597, -1890], [1611807571, 64170083, 2117774, -184411, -84629, 613256, 19033, -72466, -49319, 7445, 61308, -36252, 2372, -39284], [-1102531918, -16909048, 1057460, 320976, -52037, -561776, 675, 76513, 50404, -102703, 65379, -16185, 24565, -43235], [3156705764, 170629470, 1964420, -53469, 89451, 942304, 93223, 86108, -63939, -25377, -6425, 72915, 9767, 41565], [1916491238, -43104892, 344811, 154177, 113765, 1053208, -89779, 26512, -5215, 32006, -97447, -48054, 36787, 71932], [-946209812, 56330592, 583365, 72105, -11449, 331912, -5785, -135606, -8251, 146170, 36663, -99454, 36153, 66628], [-4597950952, 42553719, -16711696, 475124, -147586, -505456, -59040, -126950, -14122, -47122, 73474, -133095, 1614, -205869], [7370309234, 383487353, 2466583, 180905, -43043, -151405, -152543, -116782, 65385, -12444, -63329, 9568, -19315, 116614], [649601634, -60157456, 6144908, -306528, -88307, 640298, -29475, -45251, 37432, -6907, 40337, -38293, 58199, 118453], [-1401441064, 49496120, 1117360, -20770, 27050, -1949734, 66486, 86390, -112078, 197736, -9772, -82852, 17956, -12224], [-1154139232, 327681626, -3799996, -486286, -38322, 500996, -42824, 18466, 138404, -54924, 152936, -135456, 34570, -153870], [438125682, 330618190, 6778125, -321944, 256394, -2654827, -177226, 166076, -184850, 7863, 46496, 187476, 51680, 215172], [-10503300002, 145003012, -16615318, -633576, 284235, -1686994, -23713, -522471, -50312, 250411, -75149, -250965, -112639, 64165], [-6660746550, 34445892, -29047553, 403880, 76225, -2049291, -152887, 98603, -171074, 36008, -100527, -151893, -75497, 90005], [5159239244, -162540633, -12001741, -1000775, -315131, -531170, -109353, -178795, 507989, 209767, 62768, -223133, 11738, -72613], [-6216065891, -437970766, -17700678, 948560, -434044, -3089720, -341802, 63555, 275192, -120139, 314362, -87074, 92764, 10332], [-7321625958, 54396935, -32115110, -628598, 211968, 1710602, 113172, 648333, -256400, -226603, 153181, 494131, 175467, -177273], [-6979359778, 156410081, -28201259, 702918, 810764, -5101475, -18884, 158716, -586684, 630885, -169974, 154853, -59952, 485801], [4652876962, -356436356, -618120, 131429, -377095, -697858, 442637, 89306, 231595, -320949, -495543, -294027, 37025, -266669], [22146476196, -619027629, -9055352, -659031, -277469, 485768, -489609, -59009, -459631, 253192, 236208, 15652, 156078, -70278], [-11194329462, 63298724, 17652845, -574426, -25470, -411429, 1114114, 1034731, -245030, 61472, 88833, -88308, 44025, -72984], [1568133278, 155839618, -27732006, -59230, 524424, 2714300, -545244, -448374, -591082, 751526, -88142, -1082920, 68778, 113448], [830910956, 44809982, 7844938, -3936625, -721295, 7231859, 459033, -665054, 45761, 684063, 213735, -555960, 72809, 90050], [-7677717287, 83186925, -14434993, -1433341, -656531, 1970700, 465407, 1165914, 411473, -443470, 224770, 423045, 271632, -219667], [4930942531, -95234625, -27957212, -1246007, 592095, 1972904, 456201, -938662, 150705, 86815, 104364, -174502, -152312, -215010], [61373478334, -828633136, -12293812, 2688005, -140837, 317590, -657857, 542856, 915095, -840687, -23145, 515031, -455285, 301085], [21905023326, 2196295352, 10273594, 3095762, -104552, 4991730, -481512, -1889732, -399602, -20080, 192584, -696048, -387828, -693612], [-2986205737, 1189645406, 13649892, 11137916, 55108, -14675866, -408778, -993699, 409620, -525787, 822942, 443330, -146640, 349644], [35146531028, 534283452, -105255561, 5690242, 103908, -9163051, 1161710, 390544, 1047022, -148265, -316322, 693422, -166440, 1040276], [48200072312, -1505062955, 73652334, 1629471, 447477, 5802676, -925443, 1151247, 266931, -715544, -934264, 241258, -310626, 616416], [-31972128228, -20719535, -79862381, 3225978, 1780681, -3702997, 814603, 985688, -2341720, 443239, -122474, 353174, 781816, 263086], [33839538549, -2675229325, 61405549, -11077257, 26573, 5600523, 1102101, -1150022, 1710175, 881684, -531492, -872902, 583090, 798400], [43133794974, -142949273, 232547741, -3325332, -188034, -673370, 1076806, 2208777, 2186440, 574484, -1404063, 1667636, 226445, 1476584], [-28217790180, 135353026, 24981958, 4877544, -1783926, -4940964, -1666776, -30672, 302518, -1432074, 2276610, -1085010, 270400, -1750324], [-60539606088, -1593123323, -79383119, 7888041, 3251861, -5847710, -666397, -2444121, -1625159, 887979, -321382, -1047197, -213336, 540991], [-34209431502, 2187888495, 51942874, -385800, 1250922, -20885550, -1770304, -2340822, 1249590, 1228428, -2441928, 711809, -1764076, 239099], [-28824275553, 3438911413, 578696, -2711844, 1189664, 8628545, 1087936, 4622460, 1023212, -2591368, -1118787, 3040222, -802339, 1213074], [-17205166461, 1920603675, 27818484, 2056051, 2067141, -6823138, -335745, 4714168, 376843, -2020005, 620146, 1467326, 1308054, -679950], [7743068968, 3711405465, 50089855, 1672700, 604843, 14370081, 1271881, -2051840, -2301830, 936357, -2153340, 1075530, 513166, 1069250], [-45485740128, 4514005739, 52980044, 22836182, 797854, -5600446, 34724, 686875, 591422, -277955, -1179385, 2249043, 1944555, -546091], [-102366050952, -5409373078, 70949144, 12962694, 549280, 19725114, 1796252, 1937800, -5216886, 3765402, -131484, 977040, -1233636, -154872], [-243630487100, 7360549340, 121854030, -17437271, -2408531, 18815301, -1001255, -1085134, -498497, -1846715, 5775461, -1686904, 719663, -1062826], [-102322706242, 4402451312, 276917355, -2576603, -165877, 20966236, -2880503, -2268925, -793939, -2008863, -443092, 310520, 273288, 462172], [-42883931000, 1084246617, -184688116, 25242596, 4415156, 20862084, 1426572, 2841495, 3091310, -924905, -3524969, 2796649, -2660847, 2354889], [-154110932607, -237962160, 52000859, -928094, 1354482, 14024481, 3132146, -818529, 1688566, 6078046, 3155810, -1138110, -509294, -861338], [-87283984802, 4515577179, -123167849, -8731465, 168925, 38062134, 2115361, 684447, -311643, -1706309, -3435874, 2091463, 23026, 1827817], [-183583975502, 3746199120, 260884410, -12338536, -2759702, -55515934, 1984730, -3447556, -798992, 2575314, 257502, -948002, 285706, 365202], [47227043398, -2496237595, -332388009, -13885023, -1162531, 3321795, -95587, 333358, -4891151, 59392, -2215281, -1655820, -691947, 357022], [76014469210, 8754312911, 170096865, 36645637, -5020231, 12567954, 2891315, 1015129, 3671469, 1496121, 2869852, -3986495, 954554, 1180081], [-82236267268, 2928545970, -158599217, 9918726, 5176830, -43994692, 5383794, 3213996, -1477224, 1587919, -3741650, 3126971, -769572, -2991917], [5060344288, -10857038382, 126869173, -24300997, 675573, 26583060, 233015, 8341151, 1330235, 826209, -3030468, -2643946, 258608, -550262], [221335740270, 15815934660, 165800415, -8386668, -691936, -24186337, -4229310, 13453062, 237580, 97567, 872808, 194624, 3399106, -1803186], [-270261038734, 11202419369, 691654323, -22862990, 2405018, -50968405, -6773340, -1563223, 1205164, 1749916, -338613, -6000149, 1408239, -1146651], [303042767357, -7227090783, 72910858, -56280346, -663230, -39115463, -726690, -2732292, 1158270, -908992, -2307535, -1273610, -3285411, 3242498], [-220729396562, 11011108045, 44309029, -69720778, 3102206, 19918076, -6301838, -8964353, -1036502, -759484, 1499873, -6253104, -2345923, -748584], [-136317349123, -21305403210, 104356122, -13138822, -2449830, 54022588, -11613088, 2656165, -131914, -1008627, 5729354, 1126728, 4998240, -385590], [302834988372, 16463009158, -52039146, -24960980, 391646, -42862880, 4807068, -3789954, -1672858, 3476792, -2849094, 2198142, -10118192, 5522052], [-26219108237, -6102870296, 355739659, 1941030, 4723722, -6592637, -3669006, -20029283, 434810, -2505440, -1728330, -1500340, -404482, 7523584], [-103056755456, -933291420, 364353658, 14096886, -5047388, -44237486, -4171396, 8130748, 6468442, -22026896, 9551258, 6953300, -810162, -2584604], [-147347769916, 7404497820, -354223310, 27946115, -5044723, -112751556, -10689367, 5010168, -3274971, -9326183, -8692815, -446887, 4008289, 200539], [21316074681, -3437654909, -439003613, 4402638, 6119942, 5126947, 9865318, -804930, -4932164, -6082235, -8547099, 4330043, -5463797, 3420115], [-13021116183, 20622027827, 110566911, 66899975, -17090519, 7775998, -3303601, -12583600, 9059181, -1939444, 1943956, -15037667, -5002810, -9554183], [277636685078, -16789816002, 189491675, -84631606, 4642628, 65037691, 5378082, 5598618, 2271354, 4980001, -706148, -1341338, 5286366, 244796], [835921768100, -2204870571, 57056908, -26683346, 6950848, 113029542, 797978, -2255357, 728606, 4528825, -10372139, 10605447, 3396333, 14724869], [452440782866, 20182239814, -795859640, 43711894, -7036400, -63582408, 18606336, 14998726, 5832042, 2505328, -3409062, 163118, 5290802, -8033326], [-183801309654, 28525859024, -697801924, 50238942, -1328064, 112996466, -10848802, -11774130, -8188936, 7531484, 12073572, -14266102, 2623198, -366100], [-245070650818, 4316567242, -1146059452, 13966726, 12663021, -176858726, 23821285, 27215535, 1423622, 14865653, -512729, 1939589, 8829737, 338183], [-230654465122, -12706469912, -320432251, 8305551, 27245313, -35708924, 19068383, 5078253, 15241651, -1475973, -7319944, 18723612, 6338688, 8963572], [1515835603830, 22903357263, -175213622, 63302236, -11065826, -108363630, -1666798, 6130823, 11895426, -11561547, -4963497, 2538049, 6451093, -7675595], [880601230142, -19058840718, -1252382191, -65877812, 4304070, -31065215, -18934912, -5687290, -7524764, -5853315, 13879760, -11118532, 2087010, -4133090], [-359299873504, 34550542699, 20667359, 135828852, 11780524, -109441528, -32952, 8346681, 787132, -3359534, 1967811, 12207802, -2189097, -2257362], [229973190192, 3840301529, -1586936873, -86397169, 21351073, 131300822, -571419, 1643145, -3370563, -20777911, 14175582, 20541109, -611074, 248227], [278477377442, -21540115879, 1369558265, 70756910, -17070928, 254700827, -5959906, -8796949, -6679468, 1595284, 8243451, -20997549, -3181305, -6061083], [895957194534, 42818573585, -1139429138, 130625038, -10940134, -137863374, 6798138, 11722015, -15307504, -6749049, 18325039, -4161549, 1555473, -14181721], [-209198092414, 11191669004, -4077831668, -99429788, 18212936, -48210486, -3365082, 16573946, -12435914, 8111574, 1487164, 6151950, 2442266, 13740120], [80666250200, -16905400270, -623238297, -21400263, 26100299, -221204410, -14649095, -29812520, -13241789, 12380886, 29548185, -28039112, 2465337, -7766040], [523586039650, 51818304098, -521064055, 55716147, 11203190, -13932084, 4188286, -11756349, 10028647, -15853735, -6411972, -2112905, -14270180, -1767765], [223717466030, -26174206862, -2004690262, -43289562, -1247746, -46581574, -12805430, -11670992, 719370, 6283992, -33900308, -14088688, -6732420, 18278516], [765662426642, -40857430749, -3500196292, 61135940, 11483468, 50999812, 4030916, -22391717, -14189402, 14722239, 7424371, -2445229, 9861705, 1924679], [441043390625, 2955276227, 2996292601, -52552661, 4697129, -94908358, -11289817, -23001302, -15710171, 947200, 14527174, -9915325, 15520200, 4347559], [1190085229478, -32457612379, -2156717212, -142066625, -16339883, -69811086, 18287603, 24843322, -5887893, -41350587, -9825263, -6055746, -10370787, -16382354], [-329309813504, 54586935092, -1146412530, -124502519, -9907907, 65416740, -18635863, -35436150, -10297361, 17516973, -16675711, -28246727, 6010053, 14703955], [1801386974346, -30787955408, 543156106, -109678508, -10504647, 154528582, 12587481, 10948513, -15871872, 32575415, 4053249, 4530777, 13521419, -11742005], [1106794979082, -4884444978, 1253308971, -137129739, -55038383, 342320012, -22986175, 11321832, -1807811, -43069870, -34431, 8418380, -6271649, -4219658], [1823857100296, 4864215903, -3728639939, -59985133, -15473233, 265429188, -40478141, 13686791, -11211991, -19117407, 23248548, -5267287, -16085972, 1305183], [2438701587519, -15349971793, 1780074443, 330005583, -7830715, -231328013, 13676941, -11105242, 31331455, 6429718, -8097738, 4334024, 3180724, 15307570], [2347765714098, 2799609085, -1250457418, 9996081, -28296401, 133657744, -33465709, -86070941, -2630811, 29746646, 5245844, -61788848, 1564966, -10143834], [443588019278, 41263142750, -1209492642, -37512798, -4487094, -108815124, 34780568, 52157002, 59402964, -13429366, -22404170, 38672926, -2472432, 25577460], [3218709170140, -11521635295, -2974446634, 162657908, 6868298, -155471206, 34449138, 49631633, 2460842, -33910981, -13598373, 14471031, 132657, -33061009], [1074693228550, -20012737595, 3792278081, -11093118, 21240212, 102078229, 4646270, 63282247, 43368016, -56586556, -22973183, 6969557, 909481, 16428947], [-165270713926, -65833132421, -1102108071, 62220982, -14329341, -94809657, -38170993, -47578014, 3869262, -54307941, 35018688, 45802608, 32723264, -4490286], [-876551472225, 38918304914, 1437263106, 18115490, 55930626, -73215076, 17802948, 113583267, 25896738, -66762097, 3697994, 43158152, 111576, 5517218], [1915315257196, 22949691119, -5431062232, 20658022, 2277510, -362598513, -34607602, -32620104, -39626810, -2528802, -21350332, -23577786, -960952, -16003950], [1066995844538, -31968764764, -2607783651, 258626443, -37423317, -364790684, -28746503, -105198838, 31981037, 19572836, 9600079, -68131990, -5937169, -12867734], [277495335686, -176165962909, 1141727848, -179691036, -69419768, -195519624, -36278180, -1271909, 51135530, -44623621, 21694075, 4336751, 1283909, -27341121], [-1678878615952, 47370625919, -6073942570, 205703274, 42883506, -83392332, -29124836, 64467679, -27736318, 2077407, 11853471, 32731763, -1544633, 41872365], [3830984813780, -104942306840, -4770205818, -159298581, 43466012, 3942471, 15106936, -15794661, -39537931, 65366716, 5023538, -20563339, -1327870, -3558271], [1531512253574, -90516086626, -5544220426, -107385981, -27218767, 35196141, -7619163, -50613724, 7019765, 19955145, 5723735, 11129926, 30374729, 8494148], [1390801431478, -25521183265, -3819794505, -409133280, -85510150, 445264109, 27805872, -26373483, -6093342, -40872958, 28930885, -37505169, -25189251, -36475539], [3849571466516, -109111441471, 1212759884, -229324628, 62415610, -374120864, 89041380, 24346531, 67776256, 5934811, -20273661, 76946327, 1219839, 32511205], [785821521356, 166371730378, 876848252, 1730841, 94435199, -559490700, 46890327, 39707772, 16175351, 42057357, 13411485, 41439819, 14180629, 9251681], [5717031487640, -87971582004, 5008955065, 174868770, -16964080, 496880369, 33100878, -17791156, -2353158, -46214127, 54474676, 21363532, -15447998, -2553570], [201488085526, 82487837129, -1068320674, -74687907, -35155619, 226352740, -166250663, -74526945, -44698195, -32220874, 629372, -4951706, 27671386, 16488832], [-1605337691102, 99314550206, 3705279198, 119195626, -85787408, -936737720, -39793008, -57966908, -53647098, -26214912, -12860578, -45664592, -5421502, -25811320], [4423619412836, 92964542561, -1847360048, -452273854, 36300718, 1026067804, -8238520, 84169929, -48129678, -11435689, 52932325, -2863221, 16608445, -19474699], [1052430459070, 44617149750, -6341584602, -400693190, 37394854, 366522160, 126658610, 161018484, 68480166, -5349708, -103564414, 50229926, -32243866, 21891674], [1535814133135, 15998974163, -2676941644, 181558056, -10328512, -696849433, 8915844, -92017710, 29561236, -17606138, -18732105, 112187442, 66922559, 21165546], [2531596540414, -9875295402, 11361518052, -243344432, -39727157, -43448366, -90212473, 15509819, -1034152, -74783061, -3270223, -6096277, 26069447, -22462859], [-936321333006, -128305772122, -3905719373, -191368991, -65818665, 93135470, -146136465, -200626224, 29265805, -28160726, -35367325, -5519380, -44539503, 91878974], [-529465563996, 77997292099, 6179160725, -196772624, -44437198, 1363252177, 50749668, 18683147, -32518474, 63638162, 18257231, -107243371, -849553, -34105657], [4763996693948, -4042404036, 5968916640, 182124213, 131292227, -529082023, -21646641, 28464850, -53399773, -73909145, -119525107, 55689956, -45141289, 10744750], [1408448266098, -36752246731, 5902382614, -429083631, 49758329, 413343512, 51171693, 36804613, 106868945, -18377068, -35841742, -53801278, -24650280, -16475472], [-2751541920596, -104566307102, -7351323244, -247374708, 85657690, 313009132, -11169754, -74699228, -79763468, 72749288, 15135056, -33909604, -12060660, -57235000], [4424038467426, -126370587227, -5118845924, -436139470, -686594, -8482360, -73529134, -215863535, 109545620, 106137939, 6155171, 1333383, -4099887, 1391611], [2059917011764, -350651134357, 4938194374, -83278147, -67396419, -530788454, 26251907, -52425748, -142341215, 106444431, 11028637, -48443702, -39768199, -14902706], [-90607447118, -10468454516, 290364424, 780054832, -44268096, -137342728, 47399232, -32770130, -91750420, -12258938, 17647394, 20273564, 6103018, 8112468], [8144415807753, -196944373495, 6715314892, 358062623, -42496203, 5015092, 57659387, 94163232, -74006453, -48518821, -118095762, 136876478, 30560970, 48716594], [2197040450640, 71826214603, 6812874514, 575683196, 28010012, -429899456, 153746950, -16431213, -58459088, -23571319, 16422577, 77726037, 8880961, -92672261], [-361761856482, -328402573618, 17376699937, -109456914, -150022886, 247900337, 24165264, -210367464, 132831706, 17397233, -106829826, -161129956, -65992884, 16089658], [-105813032176, 62441845664, 3369295776, 798374186, -130959820, 88499970, -105548016, -65711374, 233975682, -154778380, -688980, 53001334, 18792768, 56415802], [1021249022420, -75669291613, 22779260158, 242754748, 33434974, -536243902, 81824990, 16641409, 34678826, -81662973, -92557073, 109869749, 55664097, -14928355], [-11457245284902, -241382762915, 20026076535, -466351330, -22207710, 692839623, -49034428, 16572763, -138488264, -26264746, 50291741, -30957457, 50960173, -4877767], [-1948367261944, -273229231302, 1006050416, -280998442, 90277416, -402960456, 27667316, 94229186, 27069182, -151502152, -86325326, 61997866, -49579530, 32216550], [-2977579706172, -112271605790, 10203306369, -551889452, -161122252, 1226823277, 106887340, -135360271, 71444448, -94955080, -33519133, 85201406, -66502245, -18099002], [-833606531064, -231544421429, -7085100193, 1387885058, 14372904, -817294390, -86879696, -249592047, 34740758, -30046608, 156564021, -98582448, -22328779, -12283008], [-1105195047612, -335795506202, -1898760050, -226683131, -12448983, -276049504, -100421735, -2817784, 222976727, -24200061, -13549159, -62734433, 22735737, 76599073], [-3528716611424, -429515997669, 15385397814, 793809094, 49885158, -554576969, 136966722, -22802760, -217950906, 195502272, 164542624, -12625696, 40703708, -511640], [-1470867325288, -311844244774, 3545700597, -525227871, -304159295, -2010269774, 141024369, -119649708, 11538053, -90612952, 167624571, -142666272, 63044745, -160850342], [6551400780156, -225339221235, 12549321264, -246361583, 108282975, -645903994, -71133721, 365061291, -185681287, -187934264, -7266330, 104659840, 30574524, -34412570], [8982187846370, 94065134524, 22953389996, -635986544, 153372881, 2840335840, 23489085, 25446295, -264844248, 81994959, -45108799, 176424777, -26751677, 146387063], [-1003149027202, -58256469222, 7194778681, -856443953, -63120993, -704713442, -104350865, -168256596, 125562295, -109559990, -8375909, 35527478, -195259727, 81703836], [337773197046, -381756248578, 7111630255, 284553195, -319176717, 97331684, 76998105, 41346758, 189110697, 21746166, 166677623, -329996082, 72020775, -180978210], [-10855766941272, 106015789979, 2735742116, -368342686, 190205298, -2405639560, -130976994, 213403103, -38431820, 153854397, -285980055, -35888503, 69868163, 129081201], [-5070210114846, 117509610806, -33638918476, 262358718, 6346628, 1618421854, -165213682, 89116468, -10061056, -42742254, 155636886, 31977816, 54700144, 101435926], [-3164477584558, -426001129593, 8772598390, -1376477735, 71849697, -1381641921, 131163483, 456473307, 37549739, 120058002, -116965176, -63564807, 73649874, 36573113], [-2185816933214, 228710039420, 25667233989, 553926569, 9783649, -1468549036, -153556839, 55219638, -198006415, -45298274, -71311691, 40951152, 134907803, -136961250], [9728308398360, 90226662809, -1649358314, 1387852774, 203781728, 925153930, 3087622, 266094500, 17208784, 49292648, -109593074, 110818989, 116556410, 80408563], [7755719266646, 32753045230, 14499694332, -414686554, -385918406, -434839402, 81402094, -244964526, -20970110, 241655620, 208782944, -213240982, 2608660, -160089910], [2696751032050, 647469408050, 5891353101, -383925341, -105788473, 2512685188, -368064259, 160765020, -12679135, -106165354, 68598783, -13116472, -88136309, 67499432], [-12858779526682, 692508188447, -21462840027, 846153484, 342203520, -1731364493, -36154710, 154309969, -116229206, 140305012, 136130805, 165559045, 88556725, -25463493], [-5409992262590, 268283719965, -12935380418, -1007905382, -160896622, 1669831414, 67421614, 11575711, 356453712, -228496949, -90729491, -3873449, 95576051, -40245913], [-3159130929722, -179311623972, -7755517576, -404009976, -62205716, 827355904, 35320624, -260748194, 219508064, -355655682, 71310342, 163829840, -115861622, 15523924], [15695004743422, 245281449282, -11319158920, 839695758, 60809826, -420996240, -98717108, -343500592, -74084780, -36878454, 165367636, -73001656, 11917102, -38542318], [-16425077900220, 391907295416, 4326962708, 84181872, 256269858, 2929000970, 50541248, -124621434, -2874762, 215474686, 13337856, 134619292, -28675662, 162784290], [-548633123067, 37776568269, -23628133096, 1180716408, 67568312, -619562229, 66609224, 355019342, -84752724, -459626914, 154310089, 341462784, 137387541, -54854348], [15753254606816, 362337290518, 22202389119, -334995613, -247711961, -2094321862, -143179493, -419409308, -269238493, -14376688, 111072153, -543421696, -203579393, -73377958], [14222074087738, 158880504443, -17006999398, 1288235085, 522757989, -1416295876, -33847313, 513109868, -558226215, 15748035, -56421697, 123295624, 47648039, 85617208], [-593804906070, -437539154345, 5486523050, -749618911, -391100053, 676001196, -498183581, -953844077, 87408101, 144442142, -49187624, -550299738, -97283838, -93099188], [25746317514016, -139345258080, -33745180212, -914373367, 243457715, 50473016, 358653771, 98869606, -11674389, -10873781, -53995215, 88638621, 137107489, -42085849], [424221275094, 1140739444363, 20979813377, -315785880, -71416864, -2168385837, -202175050, -267610413, 261237290, -298863398, -391816141, 159557045, -33332317, 111723147], [3125191452836, -501351763521, -57654975238, 1081062393, 64669045, -2571622074, 23194763, -31840566, 267325233, -104456347, -269790589, 201190662, -74780841, 22906722], [4186106122892, 308984622886, -22904605669, -1874355050, -263594636, 1316119967, 235685374, -124585926, -388817590, -112335727, 186060786, -240129722, 2034256, -337717844], [1026173892000, 584773949685, 11016547792, -681424980, -22548338, -1401104380, 63861154, -199911967, 194294642, -537456891, -125305255, 266258403, -270356053, -15482613], [18893777646840, 840596968991, 40776114442, -291452280, -1585978, 1351804830, 15810896, -570065196, -192949118, 160164766, 255027276, 69032349, -10905976, -173981941], [2152390267863, 260482414075, -44510505847, -757576877, 162975601, 130351145, -422315899, 54689144, 166545659, 274279406, 16193292, 50836624, -42909054, -58300714], [24268239625500, 1009889623394, -14948223195, -2338638332, 4788182, 1247136332, 319059014, 403322250, 478733546, -339989163, 106565830, 23005189, 87505440, -241294607], [14629208766640, 346689246953, -4262319562, -1397339822, 185577810, 3027213588, -387547262, 292363081, -90052804, 48547925, -44340055, -425040783, 85561879, -146433403], [-2395984090972, 76694358500, 44025155753, -575416198, -524554078, -2415300815, 88507298, -337958917, 78789018, -106775024, 152900043, 26022398, 94250387, -209962894], [24588139767512, 674886525773, -12184956743, 3469504900, 168945874, -4800352236, -112656578, -275766199, -28650500, -258419832, 162613471, 159893072, -47020985, 497332080], [17469159392168, 565366686350, -38427983516, 1212733281, 176633891, -592506324, 91435431, 972106690, 20143147, 178027883, 176545987, 514350595, 58646087, 176876725], [1473005533810, 1056700302601, -26197573245, 203539186, -266806685, -5708283715, -186701931, 414136320, -195616592, -510674669, -37103914, 299819374, -105019736, 128759118], [2148187399914, -241178247022, -59744978185, -892963327, 348041723, 1580472712, -270709235, -723315230, -165183629, 143280640, -110361435, -37804918, -54341963, 342126], [5273201935422, 931800942806, 45126618883, 343367665, 5247456, -2778033494, 634134516, 273379271, -76832047, 95077033, 408042866, -69190075, 49645270, -168089271], [45656872468968, 699473404817, 40782577594, 1195847919, 408478857, -967052714, -133810607, 404859643, -220394029, 590222208, -425624834, -401684912, -195455796, 187276446], [-26380695083572, 1331898713722, -3785897229, -1736444446, -236718206, 2311806283, 21445554, -1220672163, 367321206, 115645528, 195610789, -7234628, 209357717, 64155384], [17335883532010, 261162835228, -6935845997, -1613216721, -85660281, 682109114, 204979789, 399052194, -463313323, 519976202, 113034537, 275185466, 339218361, 103535346], [-8654637592236, -1028158943239, -1349615886, -1267836735, -700609619, 6164695424, 359714115, 232429722, 402016757, 43391613, 289569143, -515327770, 200454967, -390247590], [-9625839973668, 719564631825, 37886036016, 3766137392, 111927562, -1043320066, -108210654, -288880245, -383400034, 269151451, -125981517, -511378127, -309151275, 175262141], [-14399549342150, 2004741682497, -24370287385, 579414024, 103726774, -1329687319, -195198534, 382841622, 85592414, 79094439, -268419830, -64908439, -88737496, -312347083], [-10175107646782, 2424632449882, -31116690930, 824547578, -28886739, -2657635076, -149864659, 324035757, -152426074, -717194547, -11517297, 603656857, -153668667, -59947981], [-43100295831176, -939820659896, 2117713556, 1599667564, -94092262, -1338805026, -203568634, -328152646, 1010577624, -620657050, -308768346, 445407032, 108619458, 524526612], [37631051155238, -335013743302, -52534136936, -1341859716, -831678305, -109827906, 64607459, -51730949, -264825364, 149677827, 928008909, -868114941, -14774669, -830527619], [-17724628718682, 526696358210, 10239909440, -2778783804, -156637430, 4236405916, -1338360386, -831588914, -8192424, 293602138, 93989678, -699081808, -36398638, 272249056], [11616819443984, -348931542409, -59719930662, 17266602, -1192240466, -3658695302, 262452684, -1142477321, -446781234, 193806635, 393669079, -244213203, 240293415, -595773997], [-27762889596860, -556302536674, -53861084715, -793297594, -562613278, 323118835, -272664272, 266003756, -643749482, 618293505, -362247442, -537252666, 302008628, 574388284], [6487536275958, 1124447577787, -58973896617, 1629741166, -361236020, 118193075, 391429214, 445082063, 908418536, 965834, -112989663, 63106451, 27554461, 86067833], [16220453410327, -1618213422317, -2471273982, 1968334728, 262447164, -1672083137, -265228344, -427103670, -569697812, -337198872, -353173457, -240229260, -380333153, -1119204], [45327128355558, -699112158008, -48309505772, -2365294650, 696381871, -456926664, 593422763, 595483011, -341626450, 728781985, -331936061, 216951535, -119279635, 482876609], [6010888220910, 1930815447324, 10451131738, -2507799558, 36017326, 892804144, -454033482, 368159506, 668788790, -514118990, 791177786, -281910652, 198898646, -177491528], [1701516918530, -1049365573349, 5373866642, -1200279860, -231572328, -7029573532, 750004616, 1602340925, -371090002, 983730807, -369556181, -465145455, -315347371, 183340601], [36438155211745, -824088271129, -4191162026, 1360884598, 588435810, 5570800081, 72001850, 1364457286, 258249958, -452230314, -27232133, 696505760, 79581543, -23891728], [-15153743045943, 726085195163, -29706052637, -6410333973, 425305261, 1177517130, 734310455, 582950812, 845106653, -459945240, -221343308, 338583537, -34948630, 244294377], [38583241912206, 1984567407788, -58769329482, -1466594254, 251327743, 1726911518, -115145625, 1456203107, 172907654, 66115251, 58205971, -343628657, 342096041, -32920115], [-15017371546446, 438809233534, -88490961858, 2946015794, 42211205, -1418789138, 311496613, 882565669, -1053216370, 549913349, -95546853, -172609653, -17861899, 219907621], [15352334858862, 69037446876, 34253080541, -766059151, 41849021, -6243166550, -966773231, -979706126, -810009803, -114150942, 127985905, -875144730, 94304383, -81285928], [-42479918409744, 78814767468, 67329842774, 3629626583, 557947924, 542291183, 925857356, 1676539099, -996084835, 182465200, 603395130, -806202911, 374100030, -1041678367], [-63466366037387, 289244237561, -121161974345, 2714953979, -441242235, -5427181224, 315549823, 947972764, 13577469, 527926132, -702125460, 237929741, -66978062, -132487131], [-14380441693285, 108024020307, 31747752860, 2784049926, -860453378, -6605917149, -623251286, -1161519336, 193423518, 318411346, 613300007, -1172108832, -786610085, -163040436], [10706324015778, 696594469870, -81998547114, 120626064, -279212609, -14693024550, -428130249, 503590887, -208874272, -835195515, 698681129, 669167737, 353721191, 423789087], [-49041123782222, -1246372383023, 97319059740, -1489830938, -1238303386, 3489828040, -1124308826, -98428599, -773184284, -520129973, 1210567565, -525139585, -287404561, -842947013], [834498857560, 1377992590839, 67257440274, -3994902687, -450502385, 10563461008, -763835341, 45417615, 652053105, -307501230, 534446362, -538949982, -16275912, 608057300], [-29532615219108, 1205729769352, -13734865888, -5200747492, 335696478, -6358534636, 156068674, -434452780, -2277140164, 1577553504, -391242104, -611575518, 396986776, -145301726], [-15324412073546, -3128262345530, 99718606854, 2009379346, 1188342832, -2128066208, 681813062, 1936627356, -660298388, 595947420, -59648864, -53639496, -36361762, -268695726], [-35398334220362, 218664478947, -68932801669, -3713938964, -624652138, 2830224293, -518606470, -201525404, 177336626, -394414835, 671396180, 140066523, -360068350, -173719953], [19464085386344, -2625539977740, 96707377078, -3220927791, 1307733325, 2758312519, 1330313285, -601733328, -192111809, 906962243, -524603049, 805857278, 338962281, 39389496], [1706390298568, 1401679485013, 15178627829, 6170449030, 362180899, -11855000147, -719909795, 656682054, 6009240, -1203139993, -443630536, 9202172, -177880090, -88917776], [-6605491683686, 3849018329898, -7186995475, 3141211953, -128556311, -8346986396, 786271417, -1504668248, -546100835, 1459635780, -896170587, -872672006, -373669689, 396225764], [-49672716225151, 1712048039679, -158377256051, 3709538417, 1461186927, 3421169656, 678095749, -830772574, -123182193, 684299066, 180167196, -752745161, -614203702, 487952863], [-26714558163933, -2750076010629, -34519669896, 1938552531, -1166024031, -4970715490, -62660653, -128236944, 762847135, 215808387, -768284112, -569521086, 257977700, 426797378], [2883355132566, 5857018701758, 34454497762, 2810878361, -161109725, 6143155362, -618873601, -196676096, 763346319, 760348687, -182548407, -978030693, -409874567, 116140977], [-88091282200318, -1410099211742, 63961296545, -6089725532, 1410149673, 13180264511, 184982643, -137684607, -291311884, 660811384, -284544273, 262674109, -443009293, 644158825], [-65303939940266, 1392044800492, 55286466998, -5158440960, -64066886, 7136090212, -349816572, -1060297354, -364014394, 430876692, 251942506, -303162284, 21982208, 481942166], [-46694145773944, 2169190222185, -17490453685, 10238548942, -564921308, -17437373405, 155642500, 446646050, 564529612, -106880355, -30612342, 73467177, -51628808, 273061821], [-11341048831552, 1686284858506, -47695479504, 1138861792, -576986636, -4220331388, -859489056, 1802081424, -476234332, 736939928, -802150168, 76678466, 641390640, 113143254], [-18693744898372, -493326206486, 193280927518, 1114340898, -510831842, 8274503146, 81663578, -1362475074, 755272090, 361264810, 127409412, -977363824, -165918980, -81253208], [-14130972963596, 2458984097888, 125559908922, -3475341662, 120987220, 5485214654, -56812008, 398873530, -903207194, 1001251046, 540833688, 870530604, 14801664, -25295756], [1044845871992, 404653696733, 123797940026, -7263854924, 1542498104, -4833006607, 1428855828, 391443500, -305206928, 244704910, -977760870, 1489703482, -411194874, 179014990], [-95661092519294, 980679511617, 20421635755, -440774843, -664890019, -2070902952, -22011607, -520273095, 1282742191, -1609956433, -1343983534, 464745531, 423701538, 701520501], [-122592577584880, -672455923065, -153243595994, -7164155599, 93645039, 1350908278, -391908465, -583789951, 416378361, -1997091880, -825288436, 986557632, -1547584926, -220985258], [-74942109685904, -1157287217417, 54376364774, -6752005050, -2203919320, -6837254742, -976531726, -247754912, -825221480, -2300201900, 368867746, 376660947, -292769406, -968929595], [77477023254687, -1851402587881, 170280788058, -539230112, 1452642228, 5779780067, 561233584, -1529436864, -2195647516, -175278578, -262626951, 660287148, -542252155, 177893724], [-54773387791710, 5837952418277, -37226538758, 3223518901, -514889647, -8118923525, -1682076217, 201783747, -714897309, -1041610574, 812790460, -587980641, -136469898, -283233725], [-960311479720, -1583556827999, 64874194523, 15253482812, -1260212487, -5071236507, 711290971, 923474022, 1563435142, -458142537, -240071622, 1048445608, -276507452, 947559296], [-64178172954362, 1277000099844, 208815535586, 4583444423, 2151057335, 9171166898, 154802607, -1861137274, 909330469, 1053002195, -462549983, 1033376313, -22853483, 600350379], [-46719609694072, -21128774044, -36380635140, 12161545707, -830368011, -11827135201, -237504855, -2545588110, -770249787, 1613145857, -882752409, -2174455704, -1598671379, 552003470], [-88776038944990, 3149038201934, -30287045650, -2246278084, 1477185328, 4769308974, 1921261152, 3451757614, 205379900, -913863620, 1069023954, 1000567574, -14526074, -252451098], [-43748198406462, 2834045199784, -29929047916, -12048806423, -591068937, -1185488190, -1217896337, -1601816784, -206118977, 734398181, 136886325, -1761110653, -207369319, 739991781], [-104338114891754, -2727001079220, 37541455550, -14327858762, -542288888, 3040617912, 523205144, 404823596, 729598002, 637030412, 1552023894, -886485626, -91202898, -1124684402], [2425015897322, 1947364600092, 245069687742, -1840777008, -369103953, 18649312824, 729578179, 1563074439, -1797790704, 368721621, -194468817, -720385059, 791624501, -1288616465], [-40084676161186, 2568959424685, -1713442391, -4287417824, 2706787254, -12276158343, -1680614074, -1333940424, -1856012022, 2216760135, -352274964, 358963583, 202316714, 1042528047], [-74955597683490, -1090712538223, 51328224501, -9137662500, -3107697921, 14626972585, -1105755981, -2143220158, -634865956, -1223243147, 2251228558, -1714745496, -129203270, -1692357182], [75366665874038, 2308672016056, 136487897664, -2678665084, 1598431310, 15552110124, -403660814, -710211290, -1409019280, -160878358, 723419060, 1475004790, 196981668, 90468358], [-93381635368674, 4130672964679, 55488636148, 13848886141, 409897581, 7065024050, -430596451, 2616969239, 722277325, -1461704320, -16836864, 1627606596, -155906114, 1747876274], [32426693847526, 3981393287286, 223652080391, 260815328, -908860822, -17792045851, 2354762348, -1794381828, 1372468576, -187445151, 1208286758, -241295754, 616301380, -988286008], [-104144710281964, 2806956041318, -240604141827, 5474260840, -456108822, -12817724327, 748366318, 1736370432, -113272842, 956089659, -718644690, 980752012, 1046116358, 869473212], [-43054655468872, 1028505948884, 115673121310, -2130239082, -2223483634, -18643726992, -868395530, -4976027484, 355020966, 1597010180, 489895730, -1592520700, 1041736334, -691285296], [-6815523897670, -6261731944827, -2862710026, -614284748, 1260360968, -10829298336, 1763002484, 1394543405, -897564338, 649481499, -1825993277, 870125963, 1352953397, -572148993], [-85360433832772, 5292295872719, 6764379930, 14637574869, 1649465909, -5914315670, -48328725, 3193272244, -1589967471, 299459, -119489459, 182111498, -945125439, -456741354], [-126487027830098, 4992117433982, 29563858377, 10983111115, 1009282402, -20745793358, 2050383534, 2651103555, -1187896405, 1099728873, -361565740, -1975899567, -572679500, -740612927], [133328694441828, 313380222710, -150404830405, -8754436226, 1037325119, 8179281119, 506133357, -1247048401, -1407783454, 566941450, -2308508449, 359270245, -56824765, 698519101], [28446220156346, 596779048274, 24801724245, 9229017886, 2542881582, -3658084691, 1925417742, 2434517421, -635514794, 554051546, -2524397613, 1478416468, 511518819, -59398680], [-94120669038560, -26947019927, -20255088595, 2109348750, -1407252466, -30283625483, 960287008, 1544090247, 239801204, -1161465028, -2493024949, 1371475051, 969928611, -321782667], [26362046953606, 793447785356, -229212946532, -3101940720, -2400165020, 1975546620, -1503515036, -85756044, 1018100816, 280570260, 110245578, -1369883484, -1186537630, 816467752], [5880349527134, -5833343251844, 124623558976, -975095238, 19178841, 3853152336, -3741587847, -497336053, -1554120674, -1475859687, -48254155, 549200789, -458256013, -1318917729], [-52227985680500, 6070222145580, -141950803771, -14587654159, -2215558475, 33314580904, -1238578991, 1194008558, 1474353061, -1157969818, 556139591, 275045548, 153876073, 1245026646], [153881565676140, 1441150775808, -322520840461, 11311502228, 658161296, 11385327979, -1839133574, -1426614836, 1949464404, -951958715, 1186704026, 5393044, -483870664, 638643838], [-29809344379594, -1836786058944, -79816549696, 3953522004, 1799654394, -15162586270, 873908342, 1353510056, 1070056748, 3376173828, -2731812576, -2656008128, 671269508, 865055280], [9026178416146, -4270214791132, -413251860428, -8919216144, 962863986, 15004422298, -3325611914, -1708376184, -1668665672, 3129983384, 175865446, -3090574164, 510926322, 94234848], [-5035395943513, -1689080813025, -247457319285, -18144104829, 2053530437, 7922670237, 1992140601, 1221706382, 624029827, 260025390, 194792066, 1634380062, 1083760220, -937408976], [1195426361260, -1405859760445, 12367472828, 5636249720, 323402864, 27524029123, -663217928, -968887896, 468328240, -1771521444, 920894658, 960426648, -2242452678, 211565168], [-48357966281992, -287141278481, -315860500475, 1235089542, -131706952, -4289646942, 3284725960, 1432858001, 3955253174, -3181479106, -1286635783, 897010738, -276251811, 115841026], [39049056969984, -5253199750026, -84103686049, -2765498571, 1938260879, -22373758068, 1059179959, 6342121280, -1286874615, 1550461514, -1556457711, 1641922446, -332896029, 677665608], [28694470504300, 732207882506, -174963243112, 3903211390, -1268241332, -33634975908, -912040364, -2172495090, -210098846, -3216292684, 697409498, -3280184366, -393437630, -470411838], [53557112260109, -5917302527828, 370927574517, 5452974384, 2015272492, -24608765539, 1627061416, -173393015, -2353650224, -1554726068, 142549702, 506609866, 8768954, -1904500090], [11767965351634, -7499845943707, 26610252284, -8230214878, 35681146, -34768764524, 1539992282, -1693500919, 420161776, -1247759089, -1883046361, 1417912223, -443293807, 1345641715], [-67527096834990, 4088504543355, -209572053004, 18220611152, 887230042, -20120294864, 2147084194, 1394537189, -1211163318, 956675661, -652997311, 195692117, -1452678005, -1418312819], [-38888937542848, -1329153813767, 292131808180, -13798916575, 965493955, 11893416326, 3213724759, -316004201, -994487359, 3043329700, -1371484504, -729260744, 1840101334, 1194840246], [206865626945292, 4654814324923, -43563338423, -583827631, 682172161, -4389397172, -1714829707, -260594379, -283533129, 113856497, 1951103804, 1887397303, -693195620, -47802159], [79675903666133, -6858499476119, -119250653926, -7406488331, -6813184457, 7436206428, -5540605091, -2538749266, 3514557689, -2168374543, -408404530, -2318624670, -222051470, 859508018], [48001023227161, -7204446221636, -317116587470, 23926554648, 630876300, -23057690316, 2168725282, -371596965, 649864848, -13714955, -3559564354, 1220995876, 107636588, -1131136474], [-46045424999392, 606387421740, -109640739088, -5677361984, 1488626976, -10959846452, -1362860984, 123717164, -877176752, -201543652, 2110951490, 955668076, 913436170, 774610796], [36944261006478, -6969122373327, 299213245724, -20920482811, 5515048569, -5437371100, 1168298317, -460187891, 1874587725, 2082261314, -977777606, 4279365872, -2157386572, 4525425990], [-60746275665650, -5310336102239, -143826854778, -5024124756, -3633834920, -31296021694, 2142514856, -1283490879, 795878662, -777948421, 4036645205, -2820358703, 1520443367, -2261941443], [112366404176492, -1871633611240, -447050017747, -9438145371, -807119777, -8818398966, -189231571, -3457371423, -3659008727, 2856868581, 1368045376, -3037092772, -1059986880, -2176905840], [-36339440138562, -8541657324278, 23049122632, -2949100316, 1687384836, 5375545304, -3315137232, 5567346368, -1830558808, -2038282916, -1749678360, 4964853542, -678214816, 1339214658], [-97464285616166, -936939411292, 43020348567, 8468208780, -137765950, 37325271542, 2458993606, -3780005470, -3568237998, 153445835, 2124093240, -688542817, -1667523326, 1073369903], [-7039480631748, -1817033775866, -231492764292, 12751907661, 2762245061, 6459788212, 1902205661, 5775635362, -399755897, 1489799527, 264122351, 267021245, 1382732219, -1011850657], [-48996248877704, -599043954779, -6560984522, 9089622785, 4636851145, 19223595831, -1628192825, -2648722339, -1443672109, 2254647924, -311939524, -1418415605, 197265702, 1317500847], [-45113718526135, -8343980373065, -203465326736, 29100195315, 1367201569, -52871921654, 4411035103, 109686212, 1157134715, 582962251, 884847284, 3047887810, -944375104, -1008949462], [-15845762079114, 11117536219997, -479146166325, -15024902294, -1159320772, 3880194527, 1487013838, 7217059133, -2543950632, 274259136, -1840294177, 1451668325, 1574364871, 218555563], [121158789536946, 14363346052181, 295541859201, -12354375255, -4733712059, -20440178938, 710309247, 1750372503, -1170828603, 598904595, 5103456570, -2309526105, -1151139964, -2563822905], [-132301286448942, -15679503651386, 22771365484, 2548860540, -2233251151, -10618522190, -2816249467, 725266667, 2474796964, 833828087, -1915961993, -2638857299, 2190006589, 93502715], [138610519002966, -2318462954203, -575494446072, 14835727353, 1182927559, -18585194031, -261206739, 723980061, 2934705915, 4985206050, -4649619150, -3642353691, 1078690032, 257455229], [171498257822873, 4244317103121, -368570142370, -989441459, -4512153113, 31850786046, -1772628227, -2418454, 4792617381, -10410469791, 1301738330, 2666981524, 955151046, -3471961684], [89802374248544, -10547834949990, 23245577029, 8227327720, 5623906896, -62185250357, 2165615254, -3708973986, -2346140416, -3042516371, 395903342, 3099399516, -1457437084, 1716091038], [-145675686545520, -7618021363734, -32551445944, -33345440673, -5932014635, 2133494336, -979607111, 1198449124, 3215204509, -4115309009, 2600365603, -658882811, -200345913, -2420348069], [319127742073232, 6472634728801, 251409339010, -1045056302, -2991157310, -5326474878, -5855285994, -4389365311, 4484100556, -3237653923, -2905159399, -747068761, -289378729, 1833779811], [70413723897030, -5846253917002, -357737290666, -4645605460, -3810807517, 17284744776, -3826458745, -2961458205, -1877918568, -1203384427, 4109502673, 935091287, -1983724697, 58607521], [-56609079246894, -1291188809443, 192800755190, -6192962938, -5951496636, 65764134462, -893561016, -1654600615, -2513839604, -4592603023, 1012063667, -3354995607, -316877155, -1280004155], [108821466054593, -6370892149071, -360980241249, 3656445733, -3311407389, -58944384657, -7275097989, -4033790500, 2948070573, -3480428362, 3348945228, -5214519032, 160982278, -1093555882], [92758907478828, 8471697758262, -32383026888, 7187229214, -4126198606, 9729611102, 3266476386, 11013126666, 3164881942, 441788656, -2848904412, -770532354, -57003036, -1907793390], [199792106950538, -1890405593529, 71014447171, 31888346409, 4944852993, 7569644964, 4697504381, 1140058113, -4208035573, 994078427, 2861308638, 3475984505, 1147229394, 291985403], [291393807041877, -2876733256844, -255682590166, 9922147056, -897730488, -67531798584, 2466730846, 3003179147, 2290407256, 1521202289, -210053874, 2259972836, 3113616300, 2001692018], [2634590663678, -10885685342340, 12277630494, -22039415993, -1439301547, 1174130565, -863653291, 528544498, 1701730665, 5733222803, 2079142053, -3336624456, 1931952415, 381939546], [-347520503563748, 10290918795714, -307468341892, -10360944459, 403779591, -5167314850, 1312463223, -5355385496, 2903712755, 3298788537, 2698148043, 1939086229, -2315084693, 1687062695], [170674405923948, 7278331634432, -594804173164, -13071295612, -6230376004, 5860022252, 2467217220, -378691284, -2636805684, -3111648628, 3447744082, -2688625392, -748590214, -4039645976], [3517012887884, 11024053484616, -141984349891, 28519222893, 1800730287, 18324923158, 1436038377, 9375585083, -700422171, -3778401281, -5418888826, -1647101296, 56802566, -1050372608], [38555474872578, -530010044238, 178262192154, -28647106082, 3968516920, -24951781074, 3142687916, 3543479158, -3657840414, 2471940066, 3021221250, -5620536266, 3555073518, -5280480542], [-112803347363238, 1993200087413, 600526618494, 29472095195, 1346698847, 7476797770, 6468331499, 1639697231, -487659137, -142459548, -4238188532, 2783975094, -2474416206, 347627812], [317671124091442, 8433624448253, -35113035004, -42582160028, 2970310478, 60529472906, -1583779610, -3961955649, -463383110, 5844495863, 1745985217, -4064481635, -3282171701, -562502847], [221738611085240, -5981705953751, -616273325463, 27531854834, 5075488140, -18437824471, 5553816384, -5102090826, 3422057256, -5330526865, -1357285370, 4441724009, -2185110544, 644389513], [54352185318256, 14817236284102, 262486512428, 9236494378, 3030046042, 38408247058, 2335090550, -8269311826, -5155136946, -1192445676, 3289292324, 6243759990, -1566116536, -855300482], [205242051572414, -281016947662, 602580999763, -12274352890, -4309023042, -50018648319, 1640587888, 5568651044, -5042671026, -3400207029, 2176047188, -3969703630, -2353095130, -2162363092], [38810299506968, -10947954815671, 108865653599, -46510764912, 5458062134, -46721491575, 2069508996, 3377637879, -2818647154, -3755532212, -1490239411, 3007696629, -509232295, 2784320747], [-317301657328500, 9183352280206, -221136103651, -47376793932, -7482381667, 63206568251, -5555901561, -10507330149, -754682820, 3126918642, 6860930261, -9717616283, 39153409, -2477182163], [204587263815790, -32587187829900, 141459586418, -11034964952, -55769348, -24010563296, -527031424, -5117776274, 1883761708, -312375692, 4307345374, 2088134138, -2420760474, 763583446], [-250107575572562, 16161921172186, -6940165467, -44942527836, -4078969936, 94821170635, -7930896868, -10020476475, -4638559608, 3754744896, 2451874765, -4963902940, -1578461903, -1256552464], [-108881404148154, 2263047245616, 441854960659, -12747195944, 873851436, -13859541323, 2461173776, -273700966, 6336318690, 898701231, -4538104286, 2855068262, -16936090, 4333924490], [-205861030638750, -12101254917482, -401742100893, -4089266983, -4967513792, 15935420144, -633231924, 1015238063, -1405355247, -2785190679, -3809358454, -3121488289, -2833888462, -1083489709], [-159762342274124, 8846286580014, -284626095416, 14838860282, -12335854276, -42410238060, -2384469628, -3085481532, 4114573450, -890559858, -2675207944, 1697762662, 1693459464, -46466778], [395723346918760, 10281624335175, -65796948016, -71233290270, 457072254, 64346663890, 724748770, 4988410603, 26308480, -6126673707, 933790299, -4218391681, 148490345, -1652132521], [73257449761710, 7621474550350, -306990358881, 8286204886, -8063112680, -39258224557, 888335902, 10970507742, -575668458, -216367763, -6459085820, 440010590, -1342863154, 1925991108], [-174756216954354, -6496554241394, 1098003614, -33909372170, 7143835137, 52644495418, -2223481611, 8210216811, -6051266198, -8556579837, -346870153, 4165258343, -918907735, 256199265], [-65064592211106, -3566295594376, 460663349082, 36004240864, 4938269391, -1930324218, 4784021711, 9758671735, -9509976412, 1205271513, 3815474527, 4465188415, 4087942717, -1925262651], [-37845817773628, 8935485750460, -424798950438, 16169547514, 777281688, 28851802486, -4698491406, 5008263410, 3051654812, 2694898838, 2150093130, -9677148452, 241087588, -6183839934], [-170297631715072, 1700925781733, 111189764038, -5614574017, 8527897729, 59813105138, 6627971489, 2458409183, 6453505099, 435220892, -10263671232, 16631869912, 2514919138, 4840733050], [207029723875328, -9988331598699, 393451994772, 9822595438, -602829902, 8530046588, 8821098162, 2519601275, 2573829764, 793843097, -2844606761, -1965494365, 99483497, -4549441861], [-112292497836650, -14661560146993, -535039083319, -35175636282, -2599364716, 2192807272, -6339643536, -10002375267, -2430344238, -991360010, -390912297, -2488381816, -3733706397, -4542611908], [182069205836712, 5133115185022, 279878765034, 3847243472, -3864107620, -18725899118, -6845286240, 10369995628, -1974051720, -7821255802, 5997717088, -869344078, -1540144840, -782882478], [165164770127974, -11780857536054, 775367316447, 56658462736, 7951421546, -11428482474, 4439282534, 16302223336, -10851734446, 4426302005, 2736456018, -450810987, -3788381312, 129805349], [187223073727536, 4236455619840, 81391207737, -65404736313, -9244210763, 63873860230, -12945527391, -5675237872, -7306327545, -2080685774, 2690138747, -7653272302, 3141926085, -1684252516], [139742978158240, 4395197102403, 74048570628, -22786232779, 8246675343, -51587135286, -3038269749, 2169243061, -3622691403, 11381811434, -12370432068, -2559475346, 2339933066, 5813168032], [-391898731112110, 6900753411199, -236502883701, 18290362628, -1489008679, -55977375797, -4134500237, -11050364346, -2827318654, 1857499479, 4594036902, -1242153560, -3655654352, 3554517784], [261035902401552, 3224180810383, -568544189512, -22192189286, 5739002710, 148832534305, 5238466518, 15088349214, 6123899150, -1114373512, 1492651754, 1290484588, -3700845182, -167900992], [402448632783926, -3007029375793, 821552211314, 14044572573, -3511528751, 98131702046, 5266049699, 341166596, 4993348165, 2974641755, 6331150743, -3354558506, 2786679879, 378853974], [-106221806866252, 18309812408549, 1167006545577, -21792201257, -5502686541, 5663419640, 6033924857, -2025934905, -4586537789, 1823780569, 5487368020, 2294059111, -803355834, 1065147727], [-33219305238911, -6170985453595, -192174181769, -11493814040, -3744188704, -47256453997, 9712895492, -5888823332, 9981680350, 273286009, -5631498435, -7806255113, -5702104097, -2444301169], [128381173914104, 13879905881309, -852029630988, -32086711019, 8421217888, 22384617043, 7683869916, 3106084826, 1553824457, 5102244287, -5428238967, 9550465292, -3183945917, 4050307568], [-187682860275802, -1542042346875, 749949048820, 40959573229, -346043917, 32825590510, 4899249503, -1443530665, 489045837, -9107785200, 480293516, 5456234076, -5753850442, -2004405094], [1046171467093764, 12708486010496, -108895176113, 29153364823, 5516466273, -53687653190, -8104184939, -12336194768, -3604624789, 8350843264, -2401992599, -5353690708, 1630304447, 8911377842], [554830985280702, 25912467529374, 267099329019, -63707177466, 875123561, -13079080869, -3585470327, -5254547537, -1613109740, -1907394218, -5771181437, -93512657, 1972376749, 7430402001], [196330439312686, -20755451623460, -736142776959, -40076502732, 6743934894, -25564462679, -13965725536, -16040037442, -3812001152, 10558941309, 3069323518, -4482298406, -2921271672, 2049213028], [-132092749028574, -22631468413181, -439692677031, 4760490620, -7743643726, 77064819237, 3341528040, 13348395957, 2080714754, 1330827436, -2741090577, 1963899057, -909395381, 6600966207], [-398755332290982, -4915151137588, 618050280216, 72907653176, 13146755420, -39561501010, -6152270020, -1395897892, 4161358168, 12661310100, 442840112, -448694454, 3474653260, 1929097922], [-149577481127168, -5015894315890, 419198793577, 10275935802, 954630093, 21142336029, 1703468795, 2816948573, 5964905346, -12043318914, -2394386271, 7240166723, -27457031, -4678398793], [373010720692540, -19146126210981, 399124605175, -54806939933, 13121377715, 32691249639, -7915975313, 4767248708, 802067099, -793380728, -1864823267, 990907908, -3643085849, 9073092870], [127922467244748, -4232696484187, 1112096101037, -8225126432, -11383444950, -18566830937, -7597878652, 3600399461, -640248866, 3342000320, 6277319331, -8147863715, 4135754775, -7705676373], [-110583694897130, -3542836339278, 1042288403100, -80675269800, 2610761952, -13059402806, 942229614, 11018453768, -255172402, 1398390696, -1381933890, 6664284188, -70061368, 1995201446], [146849299251776, -20215919556846, -281349193899, 33743914031, -4717349357, 88022941408, -6199033457, -12858572810, 4130885415, 906433116, 11950031685, -6047964060, -3934508221, -7376188758], [-464033564767376, 7430861314284, 234730929276, -25778450723, -2532976789, -2594005898, 4281660879, -16316416378, 14616693807, -554650181, 4189268703, 11121114423, 1247600611, 5963319825], [-292105741897760, 11832382008061, -222689386852, -13902795650, -8476567500, -12724871092, -20148173718, -5677970654, -6054317780, -7796417196, 7512472248, -9798294847, 5919627648, -8378695237], [70817992006527, 10062745145938, -846277486513, -56126759450, 9412535810, 20528905115, -525616090, -12952813603, -12791948098, 18048047260, -10141740822, -6689665750, -1392117326, 10296714546], [-185175509527442, -614404611438, 227457530463, -36678157337, -7084264556, -10990166658, 13287482180, -13257771275, 1680546631, -2171180967, -5845092662, 4970414945, -3538172250, 2538761057], [-215973074693430, 2507601825467, 627020553604, 7667871858, 2991860170, 72127479520, -7431599826, -9609628789, 5468868216, -4377567335, 13652269085, 4955298985, 582646911, -1147710431], [241251751440456, -10052234545978, 349792398634, -16987501273, 3803449983, 5049905851, -3981913217, 7445694120, -8990322743, -8108952867, -11331474287, -1727306074, 2206967071, 2525023980], [-414070519357446, 8932894461795, -801422741183, -31458673304, 17881471252, -71653282193, 2602640414, 6810985259, -7159456414, 6914605790, 844610907, 2371139165, 763476971, 3190891619], [-47013606862322, -2429501188497, 1292075200590, -39088759050, -1173973018, 172202992538, 6226014994, 785559195, 220277400, 3217923659, -5059630327, -2079923703, 466471091, -2090879927], [386763096841298, 9342408320529, -1205363223350, -79789649295, 4466423455, -56502590365, -6953959707, 2150726099, -1637881805, 8243608790, -7898023612, 5329995057, 2543752890, 868460105], [43887053214061, -15637405601221, 499468407344, 79540114755, -2937513567, -1378994508, -15300173765, -20183953446, -4382469645, 17618399157, 11206385852, -27864570032, 9147737148, -10575474816], [-379825586408247, -11911418006783, 359051497807, 29177269809, 1764178287, -19032733641, 10792942839, 6734295754, -10254302111, 18100781144, 2422378602, -8102045476, -399118880, -3515385438], [-939370430142318, -6634284320152, 467403705152, -9712021608, -6192554218, 14753683628, -2758344228, 5061054458, 2562738526, -5101786474, -8783393966, 4144955366, -433805712, -994262220], [-406055675570460, -25350208735238, -394053112914, -55251405660, 2358724234, -83831234716, 12679322924, 13955770290, 12855546, 1012989060, -5281582426, -10349687702, -4344149848, 148118004], [-53241409447934, 44322996316430, -256874947110, 23788862932, -13357794872, 43562287824, 4456849176, -10429201444, 16356394456, -1287750314, -1071451184, 1760305056, -1749005688, -3815767936], [343050903730580, 20054383374811, -1077262096385, 132117084210, -9296969632, -153979368511, -2563317172, 12776879272, 7872591068, -11893185565, 7683702000, -3871422251, -3424789922, -8536090571], [-301658335829812, 13119684736865, -1446120522026, 13625097780, 3670931908, 63497232730, 1727651740, -12744188239, -12802685694, -3757521329, 14778541815, -6988350383, 5673396385, -9180950319], [-216375038657616, -13245455525093, 1237810536544, -51294007087, 8179034685, 3437048202, -3277440627, 6787059245, -463225347, -273894650, -6235292970, 5619073036, 1069261744, 10204287266], [-374722086758001, -5071267130263, 222238528101, 52338791416, -673432784, -83569408679, -7919809820, -7733265284, -6879211434, -7509212157, 9771668807, -9598855497, 13023804925, -1781465185], [-781619870001672, -23169381165376, 1009962957156, -74457308636, -19292934476, 12225236246, 7850851384, -24791051724, 2462920608, 5820403616, 5578727448, -16608434118, 87677160, -3484853118], [490530484647362, 34627165483286, -85564255035, 6833616915, -1276365087, -27092795678, -11719186805, -15066690496, -7695713319, 6776216970, -3246298911, -15490467116, -8872135095, -3632923468], [1125014447110500, -17238627367153, 410068926436, 4681441051, 2442054597, -78111592901, 3758814403, 76472623, -9062444451, -2301285470, 2727133952, 7694098127, 5673639542, -9032275061], [233709936838546, 4425426559857, 1692879266340, -118062199900, -5726847922, 10715129788, 1384053164, 2810562594, 19079632902, -15811062014, 2467302284, -3402235313, -6879800788, -9145349499], [776400028307030, 751935256960, 1365711830906, 21036549060, -6613096904, 20139651106, 569985212, -15339537104, 3746796988, 9181978, -17565134180, 6304236456, -151009128, -1914053028], [1009271914937174, -21223887282461, -1474134923743, -8497113974, 2160953270, -25193232459, 5290343180, 15127642173, -8817116824, 7410796690, 2327096879, 19344823213, -1719991433, 5540051963], [553667829567047, -23593501994249, 161189968189, 41993445297, -13024851173, 72612052033, -9599207489, -9718427910, -4231062715, -11243721830, 16276575868, -5532635346, 4693656022, -5687454296], [86560420496229, -5008793289697, 737135916635, 37899800058, 19065479634, 5876049053, 14980922766, 6130959538, 5509636576, 287426021, 1916598149, 4848014425, -3767355353, -17849739], [-271051393002178, -22631371741626, -725856068863, -61432773345, -11863364122, 77755671634, 19856618206, 4042413219, 7712922491, 2126263157, -3057627000, -8634264347, -3179633652, -6747878295], [279561103137622, 42966249320733, 319423262098, -39720872942, -9030244030, -38100721671, 3802637366, 2766838758, 12601824942, -9912506338, 16424562376, 5460377652, 442564460, -1434269444], [-662371229355244, 26314527314907, 1048056338575, 103876010781, -5023158787, 96947893942, -11159695857, -13682599963, 13038650737, 6778587375, -5416883340, -1856284053, -1365456778, 2290229395], [-85675885182080, -37980140260488, -1237677496763, -104336962180, -11132893707, -32433743849, -16370637445, -2358062423, 9037049780, -3861745104, 5138347203, -2697495421, 10925400543, 790185911], [699352287689978, -45480346835220, -1279618764744, -5830824970, 970246835, 52411727092, 4357998071, -2176868585, -3498901622, -8859253491, 9731103511, 9412952055, -7149320343, -7608427947], [669065501168494, 36644410358150, 854193661730, 35783246938, -17415252030, 17780910408, 5370283970, 13417608636, -3134597446, -6941076664, -1174807796, -2809043102, 9751839324, 1697544690], [1306520810771656, 55900644998354, 32782021858, 33325003039, 11405589261, -40252563933, 9745917989, 40793143458, -3035816135, -2819499865, -9913448197, 9502575688, 4245978685, -74421030], [1349301752147072, 35174807278785, 588054868304, -75334287209, 1204456937, -92173538256, -2723543889, 2062457398, 4562820231, -4668206739, -11073638461, 1927004032, -1778882969, 8734524192], [-664122587076006, 13643803191046, 272655486112, 25470846796, -7528734665, 5791055252, -11182196345, -24100055613, -20012683268, 31358633515, 8841328349, -27684764687, 5782398763, 11492506095], [193432270546016, 52477146173520, 498874818988, 13479446898, 23814444860, -63279334246, -678433348, 112666348, 3798098570, 6856748018, -16405455848, -8956314602, 1999808768, -2606259786], [719672780308608, -29278578533022, -683314732320, -79253152223, -3694597889, 200315765058, 15814926135, -11684927192, -10408803905, 17833665089, 7371524381, 402917721, 4983848353, -3544139181], [1515975734646031, -5355870056294, 597047535009, 120654813814, -10506892726, -86485782269, 5837016966, 30979555189, -14337462170, 8438567482, 17494032338, -7858753740, -1096746150, -11748705180], [1413820859942816, 8489703385891, 338491407314, -40083246325, -16913130067, -135445937838, 20649355631, -13052608620, 5881181235, -832090635, 8487216933, -12223639010, 5838434869, -44425398], [479672064601708, 27139166259220, -1353271777544, -15748060538, -13950113444, -24265943678, -8306328896, -18201012484, 6244106682, -7082733966, -6682033638, -18279537014, -8767492970, 14322092974], [-827184930719543, -2848357689311, 1428459586033, -39744804587, -1781032305, 52790252983, -13572909709, -23917548490, 15244070277, 15805257218, -374703354, -20958850842, 6383491524, -3470874252], [940172769626192, 51845732857875, -40934731314, 65054662777, -24473075896, 18918306521, -6654594752, -2627552460, 6839361601, 12278894251, 8932527775, -12063496962, -4075720471, -11661486938], [746443915863869, -3763965526097, -1383760527649, -109629224127, 13891376451, 107725751962, 18628585525, -23856536012, -11434231297, 8215645674, -5160722558, 4126841603, -233349208, 1191163607], [1030819656090700, -21828729743622, 7975142769, 125649544760, -4768541997, -231783963173, -26342793931, -13756708023, -7535325728, 9106738256, -20788965777, 360986411, -2543553473, 4648725407], [-350417974674342, 10665897098630, 551267202306, 116260990182, -9806939096, -110973925912, 3499472964, -16108083132, 13667886062, 4704866692, 2373876150, 18487423156, -12816486938, 20813534380], [456852682743562, 56644106737, -1257713176297, -31918934175, -9867540473, 178857958986, -7714221493, 6142203721, -18053087161, 5319527735, -1415295922, -10485531129, -4860303898, -1107473043], [1165370075660834, -16137896002124, -884742449143, 28376078647, 24732327446, 166064144302, -12744442718, 1011354529, -4188866445, 7029339011, 386267422, 4415136703, 11717191058, 18267052871], [1158985062210728, 1587659704092, -2688439816671, 33099824482, 6725948700, 9919092297, 16203645788, -17351262080, 9886258736, 6013855641, -3940331120, 22340249940, -1304818024, 16094583356], [49931836730946, -15027203728791, -56132475986, 13597895853, -10962529847, -109405444356, -10647192519, -6395213689, -466629203, 12220100938, -8163363652, 1397754490, -8469470018, -4554973060], [827395792677245, 8968870761497, -754648420437, 82723750368, -6661583716, 116729314019, 22565316784, 25235671922, 3152179074, 22839745107, -3474356757, 12474398179, 3693748725, 268898123], [338866270458758, 36280799449155, -317309267366, -25738548100, 2557028644, -34762594188, -14481870876, -21784287057, 5135889954, 2800420381, 11328495131, -29419566567, 3657893197, -9472889491], [876265250245798, 49782027054390, 87883847195, 32502154059, -22573316877, -82461837504, -20055190511, -12185757010, -24164448447, 25162931706, 32621025303, -32258256778, -356284385, -19638742906], [307398107081078, -9570905363992, 2418393622571, -112520966601, 16972440469, 102190463254, 6216198807, 16619656141, 5193227091, 18907369373, -10049097892, 14836620220, 974697928, -6866755152], [653557666702578, 13872229147960, 253167641016, 35703574466, -14544252012, -148421164824, -19612975076, 956063420, 7157884154, -26172287758, 6538062368, -563011284, 2202687196, -12688011904], [-265098478242145, -58555011034194, -977033763397, -34618555088, 15452313384, -17314312209, 20710485708, 24123069993, -22155389704, 12618303590, 2773183316, -9322037992, 1300150944, -11126423228], [815228764063074, 10254885690035, 1777554782397, 150492947221, -8156155715, 70915649367, -5755564575, -915294702, -15885296175, 11299828630, 7234142599, -11055347236, 6308098461, 26484604806], [-299991852326842, -27110706032350, -2065089926312, 34684190730, 11813945787, -203617189472, 9307859183, 12714120699, -2795567066, 16734340337, -3918773647, 4151637925, 6236841075, -8325172673], [1220148262631276, -8371496262144, -2155761788808, 20993285992, -30634677920, 18110111952, -17330606472, -24647546004, -2184191104, 7076448724, 14749923652, -36306366344, -15612106876, -22154637336], [899966527266738, 19933458263034, -276984610070, 10138461980, 844595294, 167584740506, 16996545174, -26749895438, -6363979064, 2417380132, 4300346288, -12826820908, -11007013208, -15476536240], [-98298005275014, -35419091017116, 383659637581, -57828439912, -13500637704, -57296866417, 14078387226, 19936890844, -13122555288, -4299153445, 5360882970, -10819702978, 14445690144, 20336012], [-736444307243798, -14052003551741, -1788279654759, -8390953748, 6822829414, -154890920517, -11734915360, 32626970149, -5246382766, -5229901752, 12309710981, 30310369379, 5360618573, 10188503553], [964187432673744, 4866052340095, 46933027979, 220480588758, -22815996438, -139504798507, -21967076928, -23725802689, -11192644964, 11821433670, 13220341773, -12749610865, 5842178105, -5959525899], [781920249896190, 62028911386510, -1730555553534, 35263319496, -7965303062, -194375024798, 19419818016, 25473892876, 27523644262, -19866793858, -4666775034, 25409906688, -6631461056, 14685926502], [-1393155520119160, -24311460302279, -3517441990011, -16725879579, 19364305921, 98144787934, -29183258857, -35798637993, -8593685859, -7756129941, -7145783458, 6661711171, -10874250092, 4445981415], [543303889843796, -38609031167581, -1007660432804, 92787710734, 26309293026, -177104502762, 8180836856, 59565352559, -6561351482, -1306121831, -12376765553, 30700055651, -1277033405, 12797216621], [-116793670199596, 17696472441954, -3249149671095, 152474026876, -2215792232, 309043711225, 18547574360, 35761486267, 7354410240, -29480142926, -4768341143, 13205629318, 9316126477, -9459912554], [-804712454681590, 84599456366671, -2805858755234, -201333496979, -8082224167, 15248606770, -14020297749, 18476236784, -12230013699, 533928395, 17719435703, -7165776658, -424636497, -1780516418], [-834016146849348, -26860104526422, -264131993660, 100757182797, 24020923681, 110492488356, -20982176347, 13235472098, -32180824569, 3728289531, -9519167159, 3085859985, 8130510021, -4013413309], [-321469979420818, -48703468283741, -1910831512512, -122783194551, -2681523629, -74498464083, -13309213851, -33163063733, 17746531715, -6005864312, 18075857900, -14643549277, -7734611742, -15942937761], [-1781247074338338, 1812209180759, 1737089025721, -51950017593, -14760080425, 287761190475, 15702887575, 20598685808, -2380641609, -26734567486, -7277897197, -2239192930, 9908729573, -13908974192], [267558823156268, -56416196079332, 1808414714680, 8618055061, -11827577299, 125445566734, 3151004345, 26615055898, -3594846409, -6400955777, -6444396281, -3849904131, 13047358423, -7367243977], [1200976350750714, -48955668112034, -3193394191476, 131259209864, -6267037920, -66469148972, 24077674254, 27932233434, -15441977150, -23773242078, -5164531604, 22034158878, -1623216310, -2289099552], [-1281479400108728, -40783057310022, -3974782708, 98453392808, 738094660, 60123841132, 20026491676, 18762037342, -15815023060, 2912544082, 1340705296, 8101464602, 5232752076, -11777302422], [472128155698634, -57476772279776, 1807378808760, -102776268938, -3300718134, 21783241512, -17202223282, -18503883114, 23490379874, 20983020904, -12091406090, -30923763806, 2701502946, 10802630782], [-1567950105498968, -9984876612951, -1984982054550, -117191724064, 35090893118, 299478242510, 5382879952, 1759729694, 5566674370, -4000461308, -25005077786, 34042797895, 7106703730, 39961269625]]
